pub(crate) fn apply_conflict_markers(s: &str) -> Result<ConflictFiles, String>Expand description
Convert a string with conflict markers into the two conflicting file contents.
pub(crate) fn apply_conflict_markers(s: &str) -> Result<ConflictFiles, String>Convert a string with conflict markers into the two conflicting file contents.