pub(crate) enum ChangeKind<'a> {
Unchanged(&'a Syntax<'a>),
IgnoredPunctuation,
ReplacedComment(&'a Syntax<'a>, &'a Syntax<'a>),
ReplacedString(&'a Syntax<'a>, &'a Syntax<'a>),
Novel,
}Variants
Unchanged(&'a Syntax<'a>)
This node is shallowly unchanged. For lists, this means that the delimiters match, but there may still be some differences in the children between LHS and RHS.
IgnoredPunctuation
Used for trailing punctuation that we might ignore.
E.g. we can ignore the last comma in [1,2,] when diffing
against [1,2]. However, we do want to highlight the comma
when diffing [1,2,] with [1,].
ReplacedComment(&'a Syntax<'a>, &'a Syntax<'a>)
ReplacedString(&'a Syntax<'a>, &'a Syntax<'a>)
Novel