difft::diff::unchanged

Function is_mostly_unchanged_list

fn is_mostly_unchanged_list(lhs: &Syntax<'_>, rhs: &Syntax<'_>) -> bool
Return true if both nodes are lists that share at least MOSTLY_UNCHANGED_MIN_COMMON_CHILDREN unique subtrees, regardless of whether their delimiters match.