difft::diff::unchanged

Function mark_unchanged

pub(crate) fn mark_unchanged<'a>(
    lhs_nodes: &[&'a Syntax<'a>],
    rhs_nodes: &[&'a Syntax<'a>],
    change_map: &mut ChangeMap<'a>,
) -> Vec<(Vec<&'a Syntax<'a>>, Vec<&'a Syntax<'a>>)>
Look for syntax nodes that are obviously the same, and set ChangeKind on them.

Split the remaining nodes into subsequences that need proper diffing, and return those subsequences.