fn apply_line(line: &str, styles: &[(SingleLineSpan, Style)]) -> StringExpand description
Return a copy of line with styles applied to all the spans
specified.
fn apply_line(line: &str, styles: &[(SingleLineSpan, Style)]) -> StringReturn a copy of line with styles applied to all the spans
specified.