pub(crate) enum DiffAttribute {
Unspecified,
AssumeText,
AssumeBinary,
}Expand description
The result of checking file’s diff and binary attributes with git check-attr.
See man gitattributes, specifically Generating diff text section.
Variants
Unspecified
The file type (text vs binary) will be autodetected.
This is the default setting, when diff attribute is not present.
AssumeText
The file should be treated as text.
Corresponds to set diff attribute, unless binary attribute is set.
AssumeBinary
The file should be treated as binary, and no diff will be shown. Sometimes this option is set for generated text files.
Corresponds to explicitly unset diff attribute (-diff), or when binary attribute is
set.