pub(crate) struct SyntaxInfo<'a> {
previous_sibling: Cell<Option<&'a Syntax<'a>>>,
next_sibling: Cell<Option<&'a Syntax<'a>>>,
prev: Cell<Option<&'a Syntax<'a>>>,
parent: Cell<Option<&'a Syntax<'a>>>,
num_ancestors: Cell<u32>,
unique_id: Cell<NonZeroU32>,
content_id: Cell<u32>,
content_is_unique_to_side: Cell<bool>,
}Expand description
Fields that are common to both Syntax::List and Syntax::Atom.
This struct uses interior mutability (Cell) extensively. In some
cases values do actually change: if we’re only considering a
subset of the AST, then, we might change e.g. next_siblingto
None when we shrink.
In other cases (e.g. unique_id) this field never changes after
AST initialisation, so this is effectively OnceCell. We instead
use a placeholder value of the same type until we’re done with
initialisation. OnceCell forces us to use an Option, which is
more runtime work.
(This is deliberately exchanging correctness-by-construction for performance.)
Fields
previous_sibling: Cell<Option<&'a Syntax<'a>>>The previous node with the same parent as this one.
next_sibling: Cell<Option<&'a Syntax<'a>>>The next node with the same parent as this one.
prev: Cell<Option<&'a Syntax<'a>>>The syntax node that occurs before this one, in a depth-first tree traversal.
parent: Cell<Option<&'a Syntax<'a>>>The parent syntax node, if present.
num_ancestors: Cell<u32>The number of nodes that are ancestors of this one.
unique_id: Cell<NonZeroU32>A number that uniquely identifies this syntax node.
content_id: Cell<u32>A number that uniquely identifies the content of this syntax node. This may be the same as nodes on the other side of the diff, or nodes at different positions.
Values are sequential, not hashes. Collisions never occur.
content_is_unique_to_side: Cell<bool>Is this the only node with this content? Ignores nodes on the other side.
Implementations
Sourceimpl<'a> SyntaxInfo<'a>
impl<'a> SyntaxInfo<'a>