fn should_ignore_last_child(
config: &TreeSitterConfig,
node: &Node<'_>,
children: &[&Syntax<'_>],
) -> boolExpand description
Does node match the ignorable trailing tokens configuration for
this language?
fn should_ignore_last_child(
config: &TreeSitterConfig,
node: &Node<'_>,
children: &[&Syntax<'_>],
) -> boolDoes node match the ignorable trailing tokens configuration for
this language?