fn split_changed_singleton_list<'a>(
lhs_nodes: &[&'a Syntax<'a>],
rhs_nodes: &[&'a Syntax<'a>],
size_threshold: u32,
) -> Vec<(ChangeState, Vec<&'a Syntax<'a>>, Vec<&'a Syntax<'a>>)>Expand description
If both sides are a single list node, and they have the same delimiter, see if they have common children that we can trivially mark as unchanged.